@@ -98,7 +98,7 @@ from starlette import status
 
 
 def test_extra_blank_line_added_nested_imports_issue_1290():
-    """Ensure isort doesn't added unecessary blank lines above nested imports.
+    """Ensure isort doesn't add unnecessary blank lines above nested imports.
     See: https://github.com/pycqa/isort/issues/1290
     """
     test_input = '''from typing import TYPE_CHECKING
@@ -1869,3 +1869,33 @@ class Bar:
     ...
 '''
     )
+
+
+def test_isort_should_produce_the_same_code_on_subsequent_runs_issue_1799(tmpdir):
+    code = """import sys
+
+if sys.version_info[:2] >= (3, 8):
+    # TODO: Import directly (no need for conditional) when `python_requires = >= 3.8`
+    from importlib.metadata import PackageNotFoundError, version  # pragma: no cover
+else:
+    from importlib_metadata import PackageNotFoundError, version  # pragma: no cover
+"""
+    config_file = tmpdir.join(".isort.cfg")
+    config_file.write(
+        """[isort]
+profile=black
+src_paths=isort,test
+line_length=100
+skip=.tox,.venv,build,dist,docs,tests
+extra_standard_library=pkg_resources,setuptools,typing
+known_test=pytest
+known_first_party=ibpt
+sections=FUTURE,STDLIB,TEST,THIRDPARTY,FIRSTPARTY,LOCALFOLDER
+import_heading_firstparty=internal
+import_heading_thirdparty=external
+"""
+    )
+    settings = isort.settings.Config(str(config_file))
+    assert isort.code(code, config=settings) == isort.code(
+        isort.code(code, config=settings), config=settings
+    )
